@@ -72,6 +72,7 @@ from pyroute2.netlink.rtnl.riprsocket import RawIPRSocket
 from pyroute2.netlink.rtnl.nsidmsg import nsidmsg
 from pyroute2.netlink.rtnl.nsinfmsg import nsinfmsg
 from pyroute2.netlink.exceptions import SkipInode
+from pyroute2.netlink.exceptions import NetlinkError
 
 from pyroute2.common import AF_MPLS
 from pyroute2.common import basestring
@@ -520,16 +521,15 @@ class RTNL_API(object):
         Please note, that link_lookup() returns list, not one
         value.
         '''
-        name = tuple(kwarg.keys())[0]
-        value = kwarg[name]
-
-        name = str(name).upper()
-        if not name.startswith('IFLA_'):
-            name = 'IFLA_%s' % (name)
-
-        return [k['index'] for k in
-                [i for i in self.get_links() if 'attrs' in i] if
-                [l for l in k['attrs'] if l[0] == name and l[1] == value]]
+        if list(kwarg) <= ['index', 'ifname']:
+            # shortcut for index and ifname
+            try:
+                return [self.link('get', **kwarg)[0]['index']]
+            except NetlinkError:
+                return []
+        else:
+            # otherwise fallback to the userspace filter
+            return [link['index'] for link in self.get_links(match=kwarg)]
     # 8<---------------------------------------------------------------
 
     # 8<---------------------------------------------------------------
@@ -1009,6 +1009,19 @@ class RTNL_API(object):
 
         Specific type notes:
 
+        ► geneve
+
+        Create GENEVE tunnel::
+
+            ip.link("add",
+                    ifname="genx",
+                    kind="geneve",
+                    geneve_id=42,
+                    geneve_remote="172.16.0.101")
+
+        Support for GENEVE over IPv6 is also included; use `geneve_remote6`
+        to configure a remote IPv6 address.
+
         ► gre
 
         Create GRE tunnel::
@@ -1348,7 +1361,7 @@ class RTNL_API(object):
         '''
         Address operations
 
-        * command -- add, delete
+        * command -- add, delete, replace, dump
         * index -- device index
         * address -- IPv4 or IPv6 address
         * mask -- address mask
@@ -1396,11 +1409,14 @@ class RTNL_API(object):
             return
 
         flags_dump = NLM_F_REQUEST | NLM_F_DUMP
-        flags_create = NLM_F_REQUEST | NLM_F_ACK | NLM_F_CREATE | NLM_F_EXCL
+        flags_base = NLM_F_REQUEST | NLM_F_ACK
+        flags_create = flags_base | NLM_F_CREATE | NLM_F_EXCL
+        flags_replace = flags_base | NLM_F_REPLACE | NLM_F_CREATE
         commands = {'add': (RTM_NEWADDR, flags_create),
                     'del': (RTM_DELADDR, flags_create),
                     'remove': (RTM_DELADDR, flags_create),
                     'delete': (RTM_DELADDR, flags_create),
+                    'replace': (RTM_NEWADDR, flags_replace),
                     'dump': (RTM_GETADDR, flags_dump)}
         (command, flags) = commands.get(command, command)
 
